import axios from 'axios'
import { ElMessage } from 'element-plus'
import router from '@/router/index'
import { getToken } from "@/utils/cache/cookies"

// 创建axios实例
const baseUrl = '/api';
const request = axios.create({
  baseURL: baseUrl,
  timeout: 200000, // 请求超时时间
  headers: { "Content-Type": "application/json;charset=utf-8", 'Authorization': getToken() },
})
// request拦截器
request.interceptors.request.use(config => {
  const token = getToken()
  if (token) {
    config.headers.Authorization = token
  }
  return config;
}, error => {
  Promise.reject(error);
});

request.interceptors.response.use(response => {
  //判断code码
  return response.data;
}, error => {
  return Promise.reject(error);
});

export default request

// 刷新token请求
function refreshToken() {
  return axios.post(`${baseUrl}auth/oauth/token`,
    {
      'grant_type': 'refresh_token',
      'refresh_token': sessionStorage.getItem("screen_token")
    }, { headers: { 'Authorization': 'Basic cGM6cGM=', 'clientType': 'SCREEN', 'Content-type': 'multipart/form-data' } });
}

let subscribers = [];

// 执行队列
function onAccessTokenFetched() {
  subscribers.forEach((callback) => {
    callback();
  })
  subscribers = [];
}

// 添加队列
function addSubscriber(callback) {
  subscribers.push(callback)
}